==> ordersprinter-2_8_15.zip: gastsystem/index.php <==
<html>
	<head>
		<title>OrderSprinter Gastbestellsystem</title>
		
		<meta http-equiv=“cache-control“ content=“no-cache“>
		<meta http-equiv=“pragma“ content=“no-cache“>
		<meta http-equiv=“expires“ content=“0″>
		<meta name="viewport" content="width=device-width, initial-scale=1"> 
		<meta http-equiv="content-type" content="text/html; charset=utf-8">
		<meta name="author" content="Stefan Pichel">
		
		<link rel="stylesheet" href="css/gueststyle.css?v=2.8.15" />
		<link rel="stylesheet" href="php/ossystem.php?command=getcss&v=2.8.15" />
		<link rel="stylesheet" href="php/3rdparty/orderstyle/jquery.mobile.icons.min.css" />
		<link rel="stylesheet" href="php/3rdparty/jquery.mobile-1.4.0.min.css" type="text/css" />
		<script src="php/3rdparty/jquery-1.11.3.min.js"></script>
		<script src="php/3rdparty/jquery.mobile-1.4.5.min.js"></script>
		<script src="js/utilities.js"></script>
	
</head>

<body>
	
<style>	
	
</style>

<script src="js/ordering.js"></script>
<script src="js/prodextras.js"></script>
<script src="js/extrasui.js"></script>

<!--first page -->
<div data-role="page" id="guest-page">
	
    <div data-role="header" data-theme="b" data-position="fixed">
        <h1><span id="roomtableheader2">OrderSprinter Gastbestellsystem</span></h1>
    </div>
    <div data-role="content">
	    
	    <div id="warningdiv" style="display:none;">
		    ACHTUNG: Eine Kommunikation mit dem Kernsystem ist derzeit nicht aktiv (möglicherweise ist kein Mitarbeiter im Kernsystem angemeldet). Bitte weisen Sie das Bedienpersonal darauf hin oder geben die Bestellung beim Kellner auf.
	    </div>
	    <div id="warningdiv2" style="display:none;">
		    ACHTUNG: Fehler im Gastbestellsystem, folgende Datei oder Verzeichnis ist schreibgeschützt: <span id="writeprotectedfile"></span>
	    </div>
	    
	    <div data-role="collapsible" data-content-theme="c" data-collapsed="false" data-theme="e" id="tableselection" style="display:none;" class="notcollapsible">
		<H2>Tischauswahl</H2>
		<p><div id="logoarea" style="text-align: center;">
			<img src="php/ossystem.php?command=getlogo" style="max-height:300px;"/>
		</div>
		<p>Bitte wählen Sie den Tisch aus:
		<div id="tableselectionbox"></div>
	    </div>
	    
	    <div data-role="collapsible" data-content-theme="c" data-collapsed="false" data-theme="e" id="tablecodediv" style="display:none;" class="notcollapsible">
		<H2>Code-Eingabe</H2>
		
		<div id="tablecodearea" style="display:none;">
			<p>Bitte geben Sie hier den Tisch-Code ein:
			<p><input class="whiteinput" type="text" id="tablecodefield" /><br>
		</div> <!-- tablecodearea -->
		
		<div id="daycodearea" style="display:none;">
			<p>Bitte geben Sie hier die Tageslosung ein:
			<p><input class="whiteinput" type="text" id="dailycodefield" /><br>
		</div> <!-- daycodearea -->
		
		<div class="ui-grid-a">
			<div class="ui-block-a"><button type="submit" data-theme="d" data-icon="back" id="codebackbtn">Zurück</button></div>
			<div class="ui-block-b"><button type="submit" data-theme="f" data-icon="check" id="submitcodesbtn">Weiter</button></div>
		</div><!-- /grid-a -->
	    </div>
	    
	    <div data-role="collapsible" data-content-theme="c" data-collapsed="false" data-theme="e" id="productsdiv" style="display:none;" class="notcollapsible">
		<H2>Auswahl der Speise oder des Getränks</H2>
		<p>Bitte wähle Sie die Gruppe bzw. die Speise oder das Getränk aus:
		
		<div id="typesdiv"></div>
		
		<div id="prodsdiv"></div>

	    </div>
        
            <div data-role="collapsible" data-content-theme="c" data-collapsed="false" data-theme="e" id="extrasdiv" style="display:none;" class="notcollapsible">
		<H2>Auswahl der Extras</H2>
		<p>Wenn zum gewählten Artikel Extras hinzugefügt werden sollen, können diese durch Anklicken der Einträge in der untenstehenden Liste ausgewählt werden. Einige Extras können mehrfach hinzugefügt werden. Jeder Klick erhöht die Anzahl bis zu einer maximal möglichen und vom Administzrator festgelegten Grenze, ab der der Zähler wieder von vorne beginnt.
		
		<div id="extrasarea"></div>
                
                <p>Soll das Produkt (mit den hier möglicherweise ausgewählten Extras) <b><span id="selectedprod"></span></b> bestellt werden?
		
		<div class="ui-grid-a">
			<div class="ui-block-a"><button type="submit" data-theme="d" data-icon="back" id="extraconfirmbackbtn">Zurück</button></div>
			<div class="ui-block-b"><button type="submit" data-theme="f" data-icon="check" id="extraconfirmbtn">JA</button></div>
		</div>
                
	    </div>
	
	    <div data-role="collapsible" data-content-theme="c" data-collapsed="false" data-theme="e" id="prodconfirmdiv" style="display:none;" class="notcollapsible">
		<H2>Bestätigung</H2>
		<p>Soll das ausgewählte Produkt <b><span id="selectedprod"></span></b> bestellt werden?
		
		<div class="ui-grid-a">
			<div class="ui-block-a"><button type="submit" data-theme="d" data-icon="back" id="prodconfirmbackbtn">Zurück</button></div>
			<div class="ui-block-b"><button type="submit" data-theme="f" data-icon="check" id="prodconfirmbtn">JA</button></div>
		</div>

	    </div>
	
	    <div data-role="collapsible" data-content-theme="c" data-collapsed="false" data-theme="e" id="askformorediv" style="display:none;" class="notcollapsible">
		<H2>Bestellvorgang</H2>
		<p>Sollen noch weitere Speisen oder Getränke bestellt werden?
		
		<div id="askformoreyesno" style="display:none;">
			<button type="submit" data-theme="d" data-icon="back" id="askformorenobtn">Abbrechen</button>
			<button type="submit" data-theme="f" data-icon="plus" id="askformoreyesbtn">Bestellung erweitern</button>
			<button type="submit" data-theme="f" data-icon="check" id="sendordersbtn">Bestellung abschicken</button>
		</div>
		<br><br>
		<p><p>Unten finden sich die für eine Bestellung ausgewählten Artikel. Mit einem Klick auf einen Artikel in der Liste kann dieser wieder <span class="emphasisForDeletion">entfernt</span> werden.
		
		

	    </div>
	 
    <p><div id="orderslist"></div><!-- comment -->
    
	<div id="timecounter"></div>
    </div> 

    <div data-role="footer" data-theme="b" id="thefooter1"> 
		<div class="ui-grid-a">
			<div class="ui-block-a">&nbsp;&nbsp;OrderSprinter</div>
			<div class="ui-block-b grid_right" id="versioninfo">2.8.15&nbsp;&nbsp;</div>
		</div><!-- /grid-a -->
	</div> 
</div>



<!--  Dialog page -->
<div data-role="dialog" id="sure" data-title="Entfernen?">
  	<div data-role="content">
    <h3 class="sure-1">?</h3>
    <p class="sure-2">?</p>
    <a href="#" class="sure-do" data-role="button" data-theme="b" data-rel="back">Ja</a>
    <a href="#" data-role="button" data-theme="c" data-rel="back">Nein</a>
  	</div>
</div>

</body>
</html>

==> ordersprinter-2_9_12.zip: gastsystem/index.php <==
<!DOCTYPE html>
<html lang="de">
	<head>
		<title>OrderSprinter Gastbestellsystem</title>
		
		<meta http-equiv=“cache-control“ content=“no-cache“>
		<meta http-equiv=“pragma“ content=“no-cache“>
		<meta http-equiv=“expires“ content=“0″>
		<meta name="viewport" content="width=device-width, initial-scale=1"> 
		<meta http-equiv="content-type" content="text/html; charset=utf-8">
		<meta name="author" content="Stefan Pichel">
		
		<link rel="stylesheet" href="css/gueststyle.css?v=2.9.12" />
		<link rel="stylesheet" href="php/ossystem.php?command=getcss&v=2.9.12" />
		<link rel="stylesheet" href="php/3rdparty/orderstyle/jquery.mobile.icons.min.css" />
		<link rel="stylesheet" href="php/3rdparty/jquery.mobile-1.4.0.min.css" type="text/css" />
		<script src="php/3rdparty/jquery-2.2.4.min.js"></script>
		<script src="php/3rdparty/jquery.mobile-1.4.5.min.js"></script>
		<script src="js/utilities.js"></script>
	
</head>

<body>
	
<style>	
	
</style>

<script src="js/ordering.js"></script>
<script src="js/prodextras.js"></script>
<script src="js/extrasui.js"></script>

<!--first page -->
<div data-role="page" id="guest-page">
	
    <div data-role="header" data-theme="b" data-position="fixed">
        <h1><span id="roomtableheader2">OrderSprinter Gastbestellsystem</span></h1>
    </div>
    <div data-role="content">
	    
	    <div id="warningdiv" style="display:none;">
		    ACHTUNG: Eine Kommunikation mit dem Kernsystem ist derzeit nicht aktiv (möglicherweise ist kein Mitarbeiter im Kernsystem angemeldet). Bitte weisen Sie das Bedienpersonal darauf hin oder geben die Bestellung beim Kellner auf.
	    </div>
	    <div id="warningdiv2" style="display:none;">
		    ACHTUNG: Fehler im Gastbestellsystem, folgende Datei oder Verzeichnis ist schreibgeschützt: <span id="writeprotectedfile"></span>
	    </div>
	    
	    <div data-role="collapsible" data-content-theme="c" data-collapsed="false" data-theme="e" id="tableselection" style="display:none;" class="notcollapsible">
		<H2>Tischauswahl</H2>
		<p><div id="logoarea" style="text-align: center;">
			<img src="php/ossystem.php?command=getlogo" style="max-height:300px;"/>
		</div>
		<p>Bitte wählen Sie den Tisch aus:
		<div id="tableselectionbox"></div>
	    </div>
	    
	    <div data-role="collapsible" data-content-theme="c" data-collapsed="false" data-theme="e" id="tablecodediv" style="display:none;" class="notcollapsible">
		<H2>Code-Eingabe</H2>
		
		<div id="tablecodearea" style="display:none;">
			<p>Bitte geben Sie hier den Tisch-Code ein:
			<p><input class="whiteinput" type="text" id="tablecodefield" /><br>
		</div> <!-- tablecodearea -->
		
		<div id="daycodearea" style="display:none;">
			<p>Bitte geben Sie hier die Tageslosung ein:
			<p><input class="whiteinput" type="text" id="dailycodefield" /><br>
		</div> <!-- daycodearea -->
		
		<div class="ui-grid-a">
			<div class="ui-block-a"><button type="submit" data-theme="d" data-icon="back" id="codebackbtn">Zurück</button></div>
			<div class="ui-block-b"><button type="submit" data-theme="f" data-icon="check" id="submitcodesbtn">Weiter</button></div>
		</div><!-- /grid-a -->
	    </div>
	    
	    <div data-role="collapsible" data-content-theme="c" data-collapsed="false" data-theme="e" id="productsdiv" style="display:none;" class="notcollapsible">
			<H2>Auswahl der Speise oder des Getränks</H2>
			<p>Bitte wähle Sie die Gruppe bzw. die Speise oder das Getränk aus:
			
			<div id="typesdiv"></div>
			
			<div id="prodsdiv"></div>
		</div>

		<div data-role="collapsible" data-content-theme="c" data-collapsed="false" data-theme="e" id="amountdiv" style="display:none;" class="notcollapsible">
			<H2>Wie häufig soll der Artikel <i><span class="selectedprod"></span></i> bestellt werden?</H2>
			<div class="ui-grid-a">
				<div class="ui-block-a" id="prodamountsdiv"></div>
				<div class="ui-block-b"><button type="submit" data-theme="f" data-icon="check" id="amountbtn">Auswahl</button></div>
			</div>
		</div>

		<div data-role="collapsible" data-content-theme="c" data-collapsed="false" data-theme="e" id="extrasdiv" style="display:none;" class="notcollapsible">
		<H2>Auswahl der Extras</H2>
		<p>Wenn zum gewählten Artikel Extras hinzugefügt werden sollen, können diese durch Anklicken der Einträge in der untenstehenden Liste ausgewählt werden. Einige Extras können mehrfach hinzugefügt werden. Jeder Klick erhöht die Anzahl bis zu einer maximal möglichen und vom Administzrator festgelegten Grenze, ab der der Zähler wieder von vorne beginnt.

		<div id="extrasarea"></div>
                
		<p>Soll das Produkt (mit den hier möglicherweise ausgewählten Extras) <b><span class="selectedprod"></span></b> bestellt werden?
		
		<div class="ui-grid-a">
			<div class="ui-block-a"><button type="submit" data-theme="d" data-icon="back" id="extraconfirmbackbtn">Zurück</button></div>
			<div class="ui-block-b"><button type="submit" data-theme="f" data-icon="check" id="extraconfirmbtn">JA</button></div>
		</div>
                
	    </div>
	
	    <div data-role="collapsible" data-content-theme="c" data-collapsed="false" data-theme="e" id="prodconfirmdiv" style="display:none;" class="notcollapsible">
		<H2>Bestätigung</H2>
		<p>Soll das ausgewählte Produkt <b><span class="selectedprod"></span></b> bestellt werden?
		
		<div class="ui-grid-a">
			<div class="ui-block-a"><button type="submit" data-theme="d" data-icon="back" id="prodconfirmbackbtn">Zurück</button></div>
			<div class="ui-block-b"><button type="submit" data-theme="f" data-icon="check" id="prodconfirmbtn">JA</button></div>
		</div>

	    </div>
	
	    <div data-role="collapsible" data-content-theme="c" data-collapsed="false" data-theme="e" id="askformorediv" style="display:none;" class="notcollapsible">
			<H2>Bestellvorgang</H2>
			<p>Sollen noch weitere Speisen oder Getränke bestellt werden?
			
			<div id="askformoreyesno">
				<button type="submit" data-theme="d" data-icon="back" id="askformorecancelbtn">Abbrechen</button>
				<button type="submit" data-theme="f" data-icon="plus" id="askformoreyesbtn">Bestellung erweitern</button>
				<button type="submit" data-theme="f" data-icon="check" id="sendordersbtn">Bestellung abschicken</button>
			</div>
			<br><br>
			<p><p>Unten finden sich die für eine Bestellung ausgewählten Artikel. Mit einem Klick auf einen Artikel in der Liste kann dieser wieder <span class="emphasisForDeletion">entfernt</span> werden.
		
	    </div>
	 
    <p><div id="orderslist"></div><!-- comment -->
    
	<div id="timecounter"></div>
    </div> 

    <div data-role="footer" data-theme="b" id="thefooter1"> 
		<div class="ui-grid-a">
			<div class="ui-block-a">&nbsp;&nbsp;OrderSprinter</div>
			<div class="ui-block-b grid_right" id="versioninfo">2.9.12&nbsp;&nbsp;</div>
		</div><!-- /grid-a -->
	</div> 
</div>



<!--  Dialog page -->
<div data-role="dialog" id="sure" data-title="Entfernen?">
  	<div data-role="content">
    <h3 class="sure-1">?</h3>
    <p class="sure-2">?</p>
    <a href="#" class="sure-do" data-role="button" data-theme="b" data-rel="back">Ja</a>
    <a href="#" data-role="button" data-theme="c" data-rel="back">Nein</a>
  	</div>
</div>

</body>
</html>
